@@ -19,7 +19,7 @@ from calibre.constants import islinux
 from calibre.gui2.library.delegates import (RatingDelegate, PubDateDelegate,
     TextDelegate, DateDelegate, CompleteDelegate, CcTextDelegate, CcLongTextDelegate,
     CcBoolDelegate, CcCommentsDelegate, CcDateDelegate, CcTemplateDelegate,
-    CcEnumDelegate, CcNumberDelegate, LanguagesDelegate)
+    CcEnumDelegate, CcNumberDelegate, LanguagesDelegate, SeriesDelegate, CcSeriesDelegate)
 from calibre.gui2.library.models import BooksModel, DeviceBooksModel
 from calibre.gui2.pin_columns import PinTableView
 from calibre.gui2.library.alternate_views import AlternateViews, setup_dnd_interface, handle_enter_press
@@ -267,10 +267,11 @@ class BooksView(QTableView):  # {{{
         self.tags_delegate = CompleteDelegate(self, ',', 'all_tag_names')
         self.authors_delegate = CompleteDelegate(self, '&', 'all_author_names', True)
         self.cc_names_delegate = CompleteDelegate(self, '&', 'all_custom', True)
-        self.series_delegate = TextDelegate(self)
+        self.series_delegate = SeriesDelegate(self)
         self.publisher_delegate = TextDelegate(self)
         self.text_delegate = TextDelegate(self)
         self.cc_text_delegate = CcTextDelegate(self)
+        self.cc_series_delegate = CcSeriesDelegate(self)
         self.cc_longtext_delegate = CcLongTextDelegate(self)
         self.cc_enum_delegate = CcEnumDelegate(self)
         self.cc_bool_delegate = CcBoolDelegate(self)
@@ -415,7 +416,11 @@ class BooksView(QTableView):  # {{{
                     current_col = self.column_map.index(column)
                     index = self.model().index(current_row, current_col)
                     qv.change_quickview_column(index)
-
+        elif action == 'remember_ondevice_width':
+            gprefs.set('ondevice_column_width', self.columnWidth(idx))
+        elif action == 'reset_ondevice_width':
+            gprefs.set('ondevice_column_width', 0)
+            self.resizeColumnToContents(idx)
         self.save_state()
 
     def create_context_menu(self, col, name, view):
@@ -469,6 +474,11 @@ class BooksView(QTableView):  # {{{
             for hcol, hname in hcols:
                 m.addAction(hname, partial(handler, action='show', column=hcol))
         ans.addSeparator()
+        if col == 'ondevice':
+            ans.addAction(_('Remember On Device column width'),
+                partial(handler, action='remember_ondevice_width'))
+            ans.addAction(_('Reset On Device column width to default'),
+                partial(handler, action='reset_ondevice_width'))
         ans.addAction(_('Shrink column if it is too wide to fit'),
                 partial(self.resize_column_to_fit, view, col))
         ans.addAction(_('Resize column to fit contents'),
@@ -596,6 +606,9 @@ class BooksView(QTableView):  # {{{
     def set_ondevice_column_visibility(self):
         col = self._model.column_map.index('ondevice')
         self.column_header.setSectionHidden(col, not self._model.device_connected)
+        w = gprefs.get('ondevice_column_width', 0)
+        if w > 0:
+            self.setColumnWidth(col, w)
         if self.is_library_view:
             self.pin_view.column_header.setSectionHidden(col, True)
 
@@ -924,7 +937,7 @@ class BooksView(QTableView):  # {{{
                     else:
                         set_item_delegate(colhead, self.cc_text_delegate)
                 elif cc['datatype'] == 'series':
-                    set_item_delegate(colhead, self.cc_text_delegate)
+                    set_item_delegate(colhead, self.cc_series_delegate)
                 elif cc['datatype'] in ('int', 'float'):
                     set_item_delegate(colhead, self.cc_number_delegate)
                 elif cc['datatype'] == 'bool':
